/**
 *
 * @param request IDBRequest | IDBTransaction
 * @public
 * @example
 * defaultGetStore()('readonly', (s) => {
 *   const promise = promisifyRequest(s.get('me'))
 *   promise.then((res) => {
 *     console.log({ res })
 *   })
 * })
 */
declare function promisifyRequest<T = undefined>(request: IDBRequest<T> | IDBTransaction): Promise<T>;
interface CreateStoreConfig {
    version?: number | undefined;
    options?: IDBObjectStoreParameters | undefined;
    deleteOnUpdate?: boolean;
    onupgradeHandler?: (store: IDBObjectStore, request: IDBOpenDBRequest, ev: IDBVersionChangeEvent) => any;
}
/**
*
* @param dbName name of database
* @param storeName name of custom store
* @public
*/
declare function createStore(dbName: string, storeName: string, config?: CreateStoreConfig): UseStore;
/**
* @public
*/
export declare type UseStore = UseStoreDefaultFunc & UseStoreGetters;
declare type UseStoreDefaultFunc = <T>(txMode: IDBTransactionMode, callback: UseStoreCallBack<T>) => Promise<T>;
declare type Methods = Omit<typeof indexDBStore, 'createStore' | 'getDefaultStore' | 'promisifyRequest'>;
declare type UseStoreCallBack<T> = (store: IDBObjectStore) => T | PromiseLike<T>;
declare type GetterCallBack = <T>(callback: UseStoreCallBack<T>) => Promise<T>;
export declare type UseStoreGetters = {
    readonly: GetterCallBack & Methods;
    readwrite: GetterCallBack & Methods;
    versionchange: GetterCallBack & Methods;
} & Methods;
declare function getDefaultStore(): UseStore;
/**
* Get a value by its key.
*
* @param key
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function get<T = any>(key: IDBValidKey | IDBKeyRange, { customStore, indexKey }?: GetConfig): Promise<T | undefined>;
/**
* Retrieves the number of records matching the given key or key range in query.
* @param key
* @public
*/
declare function count(key: IDBValidKey | IDBKeyRange, customStore?: UseStore | UseStoreDefaultFunc): Promise<number>;
/**
* Set a value with a key.
*
* @param key
* @param value
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function set(key: IDBValidKey, value: any, customStore?: UseStore | UseStoreDefaultFunc): Promise<void>;
/**
* Set multiple values at once. This is faster than calling set() multiple times.
* It's also atomic – if one of the pairs can't be added, none will be added.
*
* @param entries Array of entries, where each entry is an array of `[key, value]`.
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function setMany(entries: [IDBValidKey, any][], customStore?: UseStore | UseStoreDefaultFunc): Promise<void>;
interface GetConfigWithFilter {
    indexKey?: string;
    customStore?: UseStore | UseStoreDefaultFunc;
    filter?: IDBKeyRange;
}
interface GetConfig {
    indexKey?: string;
    customStore?: UseStore | UseStoreDefaultFunc;
}
/**
* Get multiple values by their keys
*
* @param keys
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function getMany(keys: (IDBValidKey | IDBKeyRange)[], { customStore, indexKey }?: GetConfig): Promise<any[]>;
/**
* Update a value. This lets you see the old value and update it as an atomic operation.
*
* @param key
* @param updater A callback that takes the old value and returns a new value.
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function update<T = any>(key: IDBValidKey, updater: (oldValue: T | undefined) => T, customStore?: UseStore | UseStoreDefaultFunc): Promise<void>;
/**
* Delete a particular key from the store.
*
* @param key
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function del(key: IDBValidKey, customStore?: UseStore | UseStoreDefaultFunc): Promise<void>;
/**
* Clear all values in the store.
*
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function clear(customStore?: UseStore | UseStoreDefaultFunc): Promise<void>;
declare function eachCursor(callback: (cursor: IDBCursorWithValue) => void, { customStore, indexKey, filter }: GetConfigWithFilter): Promise<void>;
/**
* Get all keys in the store.
*
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function keys(customStore?: UseStore | UseStoreDefaultFunc): Promise<IDBValidKey[]>;
/**
* Get all values in the store.
*
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function values<T = IDBValidKey>(config?: GetConfigWithFilter): Promise<T[]>;
/**
* Get all entries in the store. Each entry is an array of `[key, value]`.
*
* @param customStore Method to get a custom store. Use with caution (see the docs).
* @public
*/
declare function entries(config?: GetConfigWithFilter): Promise<[IDBValidKey, any][]>;
export declare const indexDBStore: {
    createStore: typeof createStore;
    getDefaultStore: typeof getDefaultStore;
    get: typeof get;
    set: typeof set;
    setMany: typeof setMany;
    getMany: typeof getMany;
    update: typeof update;
    del: typeof del;
    clear: typeof clear;
    keys: typeof keys;
    values: typeof values;
    entries: typeof entries;
    promisifyRequest: typeof promisifyRequest;
    count: typeof count;
    eachCursor: typeof eachCursor;
};
export default indexDBStore;
